#[non_exhaustive]pub struct MessageRetransmission { /* private fields */ }Expand description
A request to retransmit an already-sent message to one requesting device.
The client derives the wire stanza and owns all routing, encryption, session, sender-key, and persistence decisions. This type never accepts a pre-built retry stanza.
Implementations
Sourceimpl MessageRetransmission
impl MessageRetransmission
Sourcepub fn new(
chat: Jid,
requester: Jid,
message: Message,
message_id: String,
retry_count: u8,
) -> Self
pub fn new( chat: Jid, requester: Jid, message: Message, message_id: String, retry_count: u8, ) -> Self
Describe a retransmission to the device that requested it.
Sourcepub fn with_recipient(self, recipient: Jid) -> Self
pub fn with_recipient(self, recipient: Jid) -> Self
Preserve the receipt’s recipient for self-device and bot retry routes.
Sourcepub fn with_group_metadata_freshness(self, freshness: Freshness) -> Self
pub fn with_group_metadata_freshness(self, freshness: Freshness) -> Self
Select how group metadata is obtained for this operation.
pub fn chat(&self) -> &Jid
pub fn requester(&self) -> &Jid
pub fn message(&self) -> &Message
pub fn message_id(&self) -> &str
pub const fn retry_count(&self) -> u8
pub fn recipient(&self) -> Option<&Jid>
pub const fn group_metadata_freshness(&self) -> Freshness