#[non_exhaustive]pub struct RetryRequestOptions { /* private fields */ }Expand description
Options for requesting retransmission of one inbound message stanza.
Implementations
Sourceimpl RetryRequestOptions
impl RetryRequestOptions
Sourcepub const fn with_reason(self, reason: RetryReason) -> Self
pub const fn with_reason(self, reason: RetryReason) -> Self
Attach the diagnostic reason sent to the original sender.
Sourcepub const fn with_force_include_keys(self, force_include_keys: bool) -> Self
pub const fn with_force_include_keys(self, force_include_keys: bool) -> Self
Require key material even before the normal retry threshold.
Sourcepub const fn reason(self) -> RetryReason
pub const fn reason(self) -> RetryReason
The diagnostic reason sent with this request.
Sourcepub const fn force_include_keys(self) -> bool
pub const fn force_include_keys(self) -> bool
Whether key material is required before the normal retry threshold.