#[non_exhaustive]pub struct SignalSessionMigration {
pub migrated: usize,
pub skipped: usize,
pub total: usize,
pub migrated_identities: usize,
pub discarded_identities: usize,
pub skipped_identities: usize,
}Expand description
Result of moving pairwise session state between address namespaces.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.migrated: usizePairwise sessions moved to the destination namespace.
skipped: usizePairwise session lookups skipped after a storage error.
total: usizePairwise sessions found or unsuccessfully queried.
migrated_identities: usizeIdentity records moved when the destination had no identity.
discarded_identities: usizeSource identity records removed in favor of an existing destination.
skipped_identities: usizeIdentity lookups skipped after a storage error.
Implementations
Sourceimpl SignalSessionMigration
impl SignalSessionMigration
Sourcepub fn has_state_changes(self) -> bool
pub fn has_state_changes(self) -> bool
Whether any source state was moved or removed.