Module http

Module http 

Structs

HttpRequest
A simple structure to represent an HTTP request
HttpResponse
A simple structure for the HTTP response
HttpStatusError
An HTTP exchange that completed, carrying the status the client refused it on.
UreqHttpClientureq-client
HTTP client implementation using ureq for synchronous HTTP requests. Since ureq is blocking, all requests are wrapped in tokio::task::spawn_blocking.

Traits

HttpClient
Trait for executing HTTP requests in a runtime-agnostic way.