#[non_exhaustive]pub struct PluginStats {Show 16 fields
pub plugin_id: String,
pub state: PluginState,
pub health: PluginHealth,
pub callbacks_completed: u64,
pub callback_failures: u64,
pub callback_timeouts: u64,
pub task_drain_timeouts: u64,
pub task_panics: u64,
pub core_events_delivered: u64,
pub core_event_panics: u64,
pub resource_teardown_panics: u64,
pub install_tasks: u64,
pub connection_tasks: u64,
pub connection_generations: u64,
pub core_event_subscriptions: u64,
pub events: Option<PluginEventPublisherStats>,
}Available on crate feature
plugins only.Expand description
On-demand runtime snapshot for one plugin, identified only by its public manifest ID.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plugin_id: Stringstate: PluginStatehealth: PluginHealthcallbacks_completed: u64Lifecycle hooks that returned successfully.
callback_failures: u64Lifecycle hook errors and isolated panics.
callback_timeouts: u64task_drain_timeouts: u64task_panics: u64Spawned workers that panicked while running or being cancelled.
core_events_delivered: u64Core-event handler calls that returned without panicking.
core_event_panics: u64Panics isolated before they could unwind through the client’s event dispatcher.
resource_teardown_panics: u64install_tasks: u64connection_tasks: u64connection_generations: u64core_event_subscriptions: u64events: Option<PluginEventPublisherStats>Trait Implementations
Sourceimpl Clone for PluginStats
impl Clone for PluginStats
Sourcefn clone(&self) -> PluginStats
fn clone(&self) -> PluginStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginStats
impl Debug for PluginStats
impl Eq for PluginStats
Sourceimpl PartialEq for PluginStats
impl PartialEq for PluginStats
impl StructuralPartialEq for PluginStats