pub struct GroupMetadata {Show 22 fields
pub id: Jid,
pub subject: String,
pub participants: Vec<GroupParticipant>,
pub addressing_mode: AddressingMode,
pub creator: Option<Jid>,
pub creation_time: Option<u64>,
pub subject_time: Option<u64>,
pub subject_owner: Option<Jid>,
pub description: Option<String>,
pub description_id: Option<String>,
pub is_locked: bool,
pub is_announcement: bool,
pub ephemeral_expiration: u32,
pub membership_approval: bool,
pub member_add_mode: Option<MemberAddMode>,
pub member_link_mode: Option<MemberLinkMode>,
pub size: Option<u32>,
pub is_parent_group: bool,
pub parent_group_jid: Option<Jid>,
pub is_default_sub_group: bool,
pub is_general_chat: bool,
pub allow_non_admin_sub_group_creation: bool,
}Fields
id: Jidsubject: Stringparticipants: Vec<GroupParticipant>addressing_mode: AddressingModecreator: Option<Jid>Group creator JID.
creation_time: Option<u64>Group creation timestamp (Unix seconds).
subject_time: Option<u64>Subject modification timestamp (Unix seconds).
subject_owner: Option<Jid>Subject owner JID.
description: Option<String>Group description body text.
description_id: Option<String>Description ID (for conflict detection when updating).
is_locked: boolWhether the group is locked (only admins can edit group info).
is_announcement: boolWhether announcement mode is enabled (only admins can send messages).
ephemeral_expiration: u32Ephemeral message expiration in seconds (0 = disabled).
membership_approval: boolWhether membership approval is required to join.
member_add_mode: Option<MemberAddMode>Who can add members to the group.
member_link_mode: Option<MemberLinkMode>Who can use invite links.
size: Option<u32>Total participant count.
is_parent_group: boolWhether this group is a community parent group.
parent_group_jid: Option<Jid>JID of the parent community (for subgroups).
is_default_sub_group: boolWhether this is the default announcement subgroup of a community.
is_general_chat: boolWhether this is the general chat subgroup of a community.
allow_non_admin_sub_group_creation: boolWhether non-admin community members can create subgroups.