pub struct PersistenceManager { /* private fields */ }Implementations
Sourceimpl PersistenceManager
impl PersistenceManager
Sourcepub async fn new(backend: Arc<dyn Backend>) -> Result<Self, StoreError>
pub async fn new(backend: Arc<dyn Backend>) -> Result<Self, StoreError>
Create a PersistenceManager with a backend implementation.
Note: The backend should already be configured with the correct device_id (via SqliteStore::new_for_device for multi-account scenarios).
pub async fn get_device_arc(&self) -> Arc<RwLock<Device>>
pub async fn get_device_snapshot(&self) -> Device
pub fn backend(&self) -> Arc<dyn Backend>
pub async fn modify_device<F, R>(&self, modifier: F) -> R
Sourcepub async fn flush(&self) -> Result<(), StoreError>
pub async fn flush(&self) -> Result<(), StoreError>
Flush any dirty device state to the backend immediately.
Sourcepub async fn create_snapshot(
&self,
name: &str,
extra_content: Option<&[u8]>,
) -> Result<(), StoreError>
pub async fn create_snapshot( &self, name: &str, extra_content: Option<&[u8]>, ) -> Result<(), StoreError>
Triggers a snapshot of the underlying storage backend. Useful for debugging critical errors like crypto state corruption.
pub fn run_background_saver( self: Arc<Self>, runtime: Arc<dyn Runtime>, interval: Duration, )
Sourceimpl PersistenceManager
impl PersistenceManager
pub async fn process_command(&self, command: DeviceCommand)
Sourceimpl PersistenceManager
impl PersistenceManager
pub async fn get_skdm_recipients( &self, group_jid: &str, ) -> Result<Vec<Jid>, StoreError>
pub async fn add_skdm_recipients( &self, group_jid: &str, device_jids: &[Jid], ) -> Result<(), StoreError>
pub async fn clear_skdm_recipients( &self, group_jid: &str, ) -> Result<(), StoreError>